/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DLAY.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DLAY *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DLAY_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DLAY();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DLAY::Heavy_WSTD_DLAY(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_uPCq4KBN);
  numBytes += sLine_init(&sLine_myOrod6H);
  numBytes += sTabhead_init(&sTabhead_oNUjtSqh, &hTable_7926x3Sv);
  numBytes += sTabread_init(&sTabread_bO4Uo0n9, &hTable_7926x3Sv, false);
  numBytes += sTabread_init(&sTabread_MQJbVtkP, &hTable_7926x3Sv, false);
  numBytes += sLine_init(&sLine_OzLT9tNy);
  numBytes += sLine_init(&sLine_scJgD87b);
  numBytes += sLine_init(&sLine_StLxOLEC);
  numBytes += sTabhead_init(&sTabhead_QrH8jDE3, &hTable_cw8bHeZ6);
  numBytes += sTabread_init(&sTabread_iKnzqGuf, &hTable_cw8bHeZ6, false);
  numBytes += sTabread_init(&sTabread_DhFYJ0xy, &hTable_cw8bHeZ6, false);
  numBytes += sLine_init(&sLine_6LWtY6OA);
  numBytes += sTabwrite_init(&sTabwrite_SxVRcT5x, &hTable_7926x3Sv);
  numBytes += sTabwrite_init(&sTabwrite_gkkx0VgZ, &hTable_cw8bHeZ6);
  numBytes += sRPole_init(&sRPole_GczPZLXX);
  numBytes += sRPole_init(&sRPole_FWpNqiH2);
  numBytes += sRPole_init(&sRPole_zKaONJMf);
  numBytes += sDel1_init(&sDel1_7asqsh7h);
  numBytes += sLine_init(&sLine_O2K0SRyR);
  numBytes += sLine_init(&sLine_fTPoKJC7);
  numBytes += sRPole_init(&sRPole_twC5YHEN);
  numBytes += sRPole_init(&sRPole_FggNpMLl);
  numBytes += sRPole_init(&sRPole_W1XUknSA);
  numBytes += sDel1_init(&sDel1_HLGwL1JR);
  numBytes += sLine_init(&sLine_Wp2g1IH5);
  numBytes += sLine_init(&sLine_8lBULhkW);
  numBytes += sLine_init(&sLine_evl7FYEh);
  numBytes += sLine_init(&sLine_UTXAiCYF);
  numBytes += cVar_init_f(&cVar_JiYsHq0O, 0.0f);
  numBytes += cVar_init_f(&cVar_ZlUMLQSo, 0.0f);
  numBytes += cVar_init_f(&cVar_hQzDUSQG, 0.0f);
  numBytes += cVar_init_f(&cVar_gZzSSU8I, 0.0f);
  numBytes += cSlice_init(&cSlice_6p9Ls8GJ, 1, -1);
  numBytes += cVar_init_f(&cVar_kwJHUfqg, 0.5f);
  numBytes += cSlice_init(&cSlice_6h9bBmy1, 1, -1);
  numBytes += cVar_init_f(&cVar_C8jfvado, 0.2f);
  numBytes += cSlice_init(&cSlice_Oh9ijsuV, 1, -1);
  numBytes += cVar_init_f(&cVar_qYtRJvc8, 500.0f);
  numBytes += cSlice_init(&cSlice_eIyXarPB, 1, -1);
  numBytes += cVar_init_f(&cVar_dSYIrcS4, 0.25f);
  numBytes += cDelay_init(this, &cDelay_Gh39mUku, 0.0f);
  numBytes += cDelay_init(this, &cDelay_8d5Srksw, 0.0f);
  numBytes += hTable_init(&hTable_7926x3Sv, 256);
  numBytes += cDelay_init(this, &cDelay_pqwu14R0, 0.0f);
  numBytes += cDelay_init(this, &cDelay_HRx3dgvZ, 0.0f);
  numBytes += hTable_init(&hTable_cw8bHeZ6, 256);
  numBytes += cVar_init_f(&cVar_pGgS9SB2, 8000.0f);
  numBytes += cBinop_init(&cBinop_1skPyP1i, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_KgHxuHor, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_224GNFqg, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_NBbQFHat, 8000.0f);
  numBytes += cBinop_init(&cBinop_pHinPtYB, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_xkzqbu0c, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NNEzqUbh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2u2DPBE9, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_dsKKbW8E, 300.0f);
  numBytes += cBinop_init(&cBinop_WsvxntiQ, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_Q0ROTXk4, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_5lboDTLa, "del-1011-delayL");
  numBytes += sVarf_init(&sVarf_bavNXfMB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NkZdNlAI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_J7p8ddtR, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_UfOhDbZI, "del-1011-delayR");
  numBytes += sVarf_init(&sVarf_x3jtpfF0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hlSLktwM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2dsot4aa, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_B9F0hr00, 8000.0f);
  numBytes += cBinop_init(&cBinop_dET8BYgu, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_2x0yYthn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Vjywfy44, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_l29CM6kB, 8000.0f);
  numBytes += cBinop_init(&cBinop_BD5VE331, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_EG1fzdfc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mBJxROzC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EbVtG4qh, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_iVvxybfe, 300.0f);
  numBytes += cBinop_init(&cBinop_IfusATls, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_wT5MGlMC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fIncjiUm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oJyhzKuR, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Mje0XV8g, 1.0f);
  numBytes += cIf_init(&cIf_IAOGDVUp, false);
  numBytes += cIf_init(&cIf_hkNIAr4t, false);
  numBytes += cVar_init_f(&cVar_YjfbV3P2, 0.0f);
  numBytes += cVar_init_f(&cVar_BqdIorUW, 0.0f);
  numBytes += cVar_init_f(&cVar_apfruF3U, 60000.0f);
  numBytes += cVar_init_f(&cVar_F5EOfuIs, 500.0f);
  numBytes += cSlice_init(&cSlice_3qBzXGNt, 1, -1);
  numBytes += cSlice_init(&cSlice_SZYl4vyc, 1, -1);
  numBytes += cVar_init_f(&cVar_gP0mbNOU, 0.0f);
  numBytes += cIf_init(&cIf_vY0viXIF, false);
  numBytes += cBinop_init(&cBinop_7OtzAZTd, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_Pra0GLr2, 120.0f);
  numBytes += cBinop_init(&cBinop_5tR11xNT, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_2DnJNMZC, 0.0f); // __mul
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DLAY::~Heavy_WSTD_DLAY() {
  hTable_free(&hTable_7926x3Sv);
  hTable_free(&hTable_cw8bHeZ6);
}

HvTable *Heavy_WSTD_DLAY::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x33B09DD4: return &hTable_7926x3Sv; // del-1011-delayL
    case 0xF057CB49: return &hTable_cw8bHeZ6; // del-1011-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DLAY::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xB6A8F09D: { // Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tvsOHhHF_sendMessage);
      break;
    }
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_su2Pli4W_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UkjPPDpj_sendMessage);
      break;
    }
    case 0x4A331B66: { // Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HMZVD8De_sendMessage);
      break;
    }
    case 0x58E5C2DB: { // Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ujzFHYb5_sendMessage);
      break;
    }
    case 0x49107604: { // TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PjpFFJXI_sendMessage);
      break;
    }
    case 0xD640D30E: { // 1011-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Qu9G8O3H_sendMessage);
      break;
    }
    case 0xC82F3AD1: { // 1011-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FecfLnw5_sendMessage);
      break;
    }
    case 0x6E7C47FF: { // 1011-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sClDORxF_sendMessage);
      break;
    }
    case 0xD896CBA3: { // 1011-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XMPgWty8_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MkD0rsbk_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7e2UGMwg_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DLAY::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Cross";
        info->hash = 0xB6A8F09D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 1: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Sync";
        info->hash = 0x4A331B66;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "Time";
        info->hash = 0x58E5C2DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 5: {
        info->name = "TimeSync";
        info->hash = 0x49107604;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 6;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DLAY::cVar_JiYsHq0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U4ik4Z3D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_ZlUMLQSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V1QLpMKv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_hQzDUSQG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_20RbRPEH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_gZzSSU8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FgfnudKC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_MQdkcQy4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6p9Ls8GJ, 0, m, &cSlice_6p9Ls8GJ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_6p9Ls8GJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LByVWikV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LByVWikV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_kwJHUfqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LByVWikV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_LByVWikV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sClDORxF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_jdzPpzA6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6h9bBmy1, 0, m, &cSlice_6h9bBmy1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6XMvJp1S_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_6h9bBmy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_E24GFlK8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_E24GFlK8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_C8jfvado_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_E24GFlK8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_E24GFlK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Qu9G8O3H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_n90okzJb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Oh9ijsuV, 0, m, &cSlice_Oh9ijsuV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MQdkcQy4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_Oh9ijsuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_h7W4Tutx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_h7W4Tutx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_qYtRJvc8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_h7W4Tutx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_h7W4Tutx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XMPgWty8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_8roFm7Xa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_XmTeikDe_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_XmTeikDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_waBmQ5m2_sendMessage);
}

void Heavy_WSTD_DLAY::cUnop_shUSZOve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ELffi3de_sendMessage(_c, 0, m);
  cMsg_Y6w0PjZX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cUnop_qWTHNQpy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7sTZMEfy_sendMessage(_c, 0, m);
  cMsg_tUV9Tbcu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_waBmQ5m2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Z8zEre3Q_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Z8zEre3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vbuPbBA3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uKK5jGHk_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_uKK5jGHk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3EbWr2cv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_vbuPbBA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_nX4lD3pG_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_nX4lD3pG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5xS4DwEx_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_3EbWr2cv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_VCWAIZhs_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_VCWAIZhs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7Ymw9qoC_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_5xS4DwEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_shUSZOve_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_7Ymw9qoC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_qWTHNQpy_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_4VTo2Kbw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_35XHvb3W_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_35XHvb3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_J6eZNFcw_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_J6eZNFcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_89VUwOLa_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_89VUwOLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_STUocZAf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Obq4k0xy_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_STUocZAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ga2QpfTw_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_Obq4k0xy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zve6ma57_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_ga2QpfTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_HlrBjMXK_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_zve6ma57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_k1N9pZKF_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_k1N9pZKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_IiKUi83o_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_IiKUi83o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n7d850Je_sendMessage(_c, 0, m);
  cMsg_m3ykVZEN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_HlrBjMXK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fkaVl5vX_sendMessage(_c, 0, m);
  cMsg_2OSfud9g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_6XMvJp1S_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_eIyXarPB, 0, m, &cSlice_eIyXarPB_sendMessage);
      break;
    }
    default: {
      cSwitchcase_n90okzJb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_eIyXarPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_c1ddE1qb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_c1ddE1qb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_dSYIrcS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_c1ddE1qb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_c1ddE1qb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FecfLnw5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_o6iKFmqA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ko5VrUFZ_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_ko5VrUFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_8r8nkV8I_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_Gh39mUku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Gh39mUku, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8d5Srksw, 0, m, &cDelay_8d5Srksw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Gh39mUku, 0, m, &cDelay_Gh39mUku_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_SxVRcT5x, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_8d5Srksw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8d5Srksw, m);
  cMsg_VMIsRzmh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_6rxn2sQx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Yg3AnBI2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_TtOKXV3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xMcaFkDa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_7926x3Sv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d9LM1E8V_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Gh39mUku, 2, m, &cDelay_Gh39mUku_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ue3hOBa3_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_xMcaFkDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_7926x3Sv, 0, m, &hTable_7926x3Sv_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_8r8nkV8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_TtOKXV3T_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_VMIsRzmh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_7926x3Sv, 0, m, &hTable_7926x3Sv_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_Ue3hOBa3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Gh39mUku, 0, m, &cDelay_Gh39mUku_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_d9LM1E8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_8d5Srksw, 2, m, &cDelay_8d5Srksw_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_Yg3AnBI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_SxVRcT5x, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_qCpV1uVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oKyK5Xba_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_oKyK5Xba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_yoVi4ZOu_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_pqwu14R0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pqwu14R0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HRx3dgvZ, 0, m, &cDelay_HRx3dgvZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pqwu14R0, 0, m, &cDelay_pqwu14R0_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_gkkx0VgZ, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_HRx3dgvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HRx3dgvZ, m);
  cMsg_SsLJWjGb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_VCKoBuVG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_qbzlC9iO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_slCAPRZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h4b6Q13l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_cw8bHeZ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kqMRngnJ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pqwu14R0, 2, m, &cDelay_pqwu14R0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j1Fn0u03_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_h4b6Q13l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_cw8bHeZ6, 0, m, &hTable_cw8bHeZ6_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_yoVi4ZOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_slCAPRZa_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_SsLJWjGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_cw8bHeZ6, 0, m, &hTable_cw8bHeZ6_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_j1Fn0u03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pqwu14R0, 0, m, &cDelay_pqwu14R0_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_kqMRngnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_HRx3dgvZ, 2, m, &cDelay_HRx3dgvZ_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_qbzlC9iO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_gkkx0VgZ, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_pGgS9SB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1skPyP1i, HV_BINOP_MULTIPLY, 0, m, &cBinop_1skPyP1i_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_BAYV0xGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8w11Zo3G_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_8w11Zo3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cSBIsUpY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_1skPyP1i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_8S35bcMe_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_oGpyh53M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1skPyP1i, HV_BINOP_MULTIPLY, 1, m, &cBinop_1skPyP1i_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_cSBIsUpY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_oGpyh53M_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_8S35bcMe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_yU5mGpdd_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_yU5mGpdd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_O3PmU0Fg_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_224GNFqg, m);
}

void Heavy_WSTD_DLAY::cBinop_O3PmU0Fg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_KgHxuHor, m);
}

void Heavy_WSTD_DLAY::cVar_NBbQFHat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pHinPtYB, HV_BINOP_MULTIPLY, 0, m, &cBinop_pHinPtYB_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_IXX8RKVk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JzlKbxSm_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_JzlKbxSm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XE6NtNtw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_pHinPtYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_LHH1BXrO_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Dd3xqyJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pHinPtYB, HV_BINOP_MULTIPLY, 1, m, &cBinop_pHinPtYB_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_XE6NtNtw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Dd3xqyJH_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_LHH1BXrO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_HANt8vbk_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_HANt8vbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_1pXE15KY_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_NNEzqUbh, m);
}

void Heavy_WSTD_DLAY::cBinop_1pXE15KY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_xkzqbu0c, m);
}

void Heavy_WSTD_DLAY::cBinop_9biRsh1G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_kRRVEdVp_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_kRRVEdVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_HDPVfUct_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_KJCnUNNX_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_dsKKbW8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_aWOLlpf0_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_gJENzuI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_INzt2aD4_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_INzt2aD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WsvxntiQ, HV_BINOP_DIVIDE, 1, m, &cBinop_WsvxntiQ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_HDPVfUct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_s4uivo9J_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_s4uivo9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Q0ROTXk4, m);
}

void Heavy_WSTD_DLAY::cMsg_FdscIbaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_696b4rKa_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_696b4rKa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_9biRsh1G_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_KJCnUNNX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2u2DPBE9, m);
}

void Heavy_WSTD_DLAY::cBinop_aWOLlpf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_Q9EPVC2F_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Q9EPVC2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WsvxntiQ, HV_BINOP_DIVIDE, 0, m, &cBinop_WsvxntiQ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_WsvxntiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FdscIbaH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_HChowd2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7ZSSixCW_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_7ZSSixCW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_4PetTCMW_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_5lboDTLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GU8atioA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_QuPCKAfA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ug0cJA6A_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_bavNXfMB, m);
}

void Heavy_WSTD_DLAY::cBinop_4PetTCMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_NkZdNlAI, m);
}

void Heavy_WSTD_DLAY::cMsg_GU8atioA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QuPCKAfA_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ug0cJA6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_J7p8ddtR, m);
}

void Heavy_WSTD_DLAY::cMsg_sagq6xtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WRkY4UOp_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_WRkY4UOp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_8ouM4FDa_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_UfOhDbZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QtE8Olhu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_5f0a84Ld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_LZyL0pOq_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_x3jtpfF0, m);
}

void Heavy_WSTD_DLAY::cBinop_8ouM4FDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_hlSLktwM, m);
}

void Heavy_WSTD_DLAY::cMsg_QtE8Olhu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5f0a84Ld_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_LZyL0pOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2dsot4aa, m);
}

void Heavy_WSTD_DLAY::cVar_B9F0hr00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dET8BYgu, HV_BINOP_MULTIPLY, 0, m, &cBinop_dET8BYgu_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_kGFRQMK0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ERVm3KPT_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_ERVm3KPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DPQ8Q2sK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_dET8BYgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_aMAIZl7F_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_pfb7qdCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dET8BYgu, HV_BINOP_MULTIPLY, 1, m, &cBinop_dET8BYgu_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_DPQ8Q2sK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_pfb7qdCU_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_aMAIZl7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_QplMYuSL_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_QplMYuSL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_NVSeOZD2_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Vjywfy44, m);
}

void Heavy_WSTD_DLAY::cBinop_NVSeOZD2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2x0yYthn, m);
}

void Heavy_WSTD_DLAY::cVar_l29CM6kB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BD5VE331, HV_BINOP_MULTIPLY, 0, m, &cBinop_BD5VE331_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_lhnW9Nf6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qD6Cfd96_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_qD6Cfd96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WgRLbFeb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_BD5VE331_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_4k5QKoiu_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_dhnBAJDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BD5VE331, HV_BINOP_MULTIPLY, 1, m, &cBinop_BD5VE331_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_WgRLbFeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_dhnBAJDq_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_4k5QKoiu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_HmBs65oR_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_HmBs65oR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Zj351ysT_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_mBJxROzC, m);
}

void Heavy_WSTD_DLAY::cBinop_Zj351ysT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_EG1fzdfc, m);
}

void Heavy_WSTD_DLAY::cBinop_2ypCwzCO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_nSYwrB8p_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_nSYwrB8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_bZ9u1j2d_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_VBFpoJui_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_iVvxybfe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_tuvCfGBh_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_5vxKq0ey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yaxhyqVl_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_yaxhyqVl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IfusATls, HV_BINOP_DIVIDE, 1, m, &cBinop_IfusATls_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_bZ9u1j2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_PHcsnj3X_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_PHcsnj3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_wT5MGlMC, m);
}

void Heavy_WSTD_DLAY::cMsg_fYT46wqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_pChy46Pj_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_pChy46Pj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_2ypCwzCO_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_VBFpoJui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_EbVtG4qh, m);
}

void Heavy_WSTD_DLAY::cBinop_tuvCfGBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_4nQ5fJ2p_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_4nQ5fJ2p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IfusATls, HV_BINOP_DIVIDE, 0, m, &cBinop_IfusATls_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_IfusATls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fYT46wqJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_ELffi3de_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OzLT9tNy, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_7sTZMEfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uPCq4KBN, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_tUV9Tbcu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_scJgD87b, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_Y6w0PjZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6LWtY6OA, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_2OSfud9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8lBULhkW, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_n7d850Je_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fTPoKJC7, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_fkaVl5vX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UTXAiCYF, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_m3ykVZEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_evl7FYEh, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_av0A6fui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_myOrod6H, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_WPQ4uvUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_StLxOLEC, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_7pVWNaUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_O2K0SRyR, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_zcEWaIed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Wp2g1IH5, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_Mje0XV8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xNCNhnJr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sQrpIVr6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_sFzBnp5f_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_xNCNhnJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Mje0XV8g, 1, m, &cVar_Mje0XV8g_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_IAOGDVUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_ZlUMLQSo, 0, m, &cVar_ZlUMLQSo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cIf_hkNIAr4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_ZlUMLQSo, 0, m, &cVar_ZlUMLQSo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_YjfbV3P2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hkNIAr4t, 0, m, &cIf_hkNIAr4t_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_BqdIorUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IAOGDVUp, 0, m, &cIf_IAOGDVUp_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_apfruF3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5tR11xNT, HV_BINOP_DIVIDE, 0, m, &cBinop_5tR11xNT_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_F5EOfuIs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2DnJNMZC, HV_BINOP_MULTIPLY, 1, m, &cBinop_2DnJNMZC_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_UNXGPv6B_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3qBzXGNt, 0, m, &cSlice_3qBzXGNt_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SZYl4vyc, 0, m, &cSlice_SZYl4vyc_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UWTgNOPW_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d1gMNPA8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_3qBzXGNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_gP0mbNOU, 0, m, &cVar_gP0mbNOU_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_gP0mbNOU, 0, m, &cVar_gP0mbNOU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cSlice_SZYl4vyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_7OtzAZTd, HV_BINOP_NEQ, 1, m, &cBinop_7OtzAZTd_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_gP0mbNOU, 1, m, &cVar_gP0mbNOU_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_7OtzAZTd, HV_BINOP_NEQ, 1, m, &cBinop_7OtzAZTd_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_gP0mbNOU, 1, m, &cVar_gP0mbNOU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_gP0mbNOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_5YHa2BTH_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_vY0viXIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WdHjZiaR_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N5F4GrJY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cCast_WdHjZiaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7OtzAZTd, HV_BINOP_NEQ, 1, m, &cBinop_7OtzAZTd_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_N5F4GrJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gP0mbNOU, 0, m, &cVar_gP0mbNOU_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_7OtzAZTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vY0viXIF, 1, m, &cIf_vY0viXIF_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_UWTgNOPW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7OtzAZTd, HV_BINOP_NEQ, 0, m, &cBinop_7OtzAZTd_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_d1gMNPA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vY0viXIF, 0, m, &cIf_vY0viXIF_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_Pra0GLr2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j7AzyIa8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F1p5R7BG_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_9QqpRRxf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XPPouK35_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1AxWHjeG_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nuP9C3zU_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FHrlcNZ1_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YWo21gHV_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dkml0jSK_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ot61OeJw_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_umIH8hZR_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CNcU6Vfk_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_owGL5w04_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RbpSlcrw_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Vfqik9ze_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LX3ZeqI9_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cCast_XPPouK35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TFz9yHS7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_1AxWHjeG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pWrvW9z0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_nuP9C3zU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9aOiP6jF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_FHrlcNZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cIOeOfoW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_YWo21gHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6ZaC85Zv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_dkml0jSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r48NksEV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_Ot61OeJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_plHFKk5h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_umIH8hZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d421UpGx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_CNcU6Vfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h8ig0Gb0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_owGL5w04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sfEwL9uz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_RbpSlcrw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_780GsYow_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_Vfqik9ze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JJuc3ZHV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_LX3ZeqI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z2XVEp3C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_5tR11xNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2DnJNMZC, HV_BINOP_MULTIPLY, 0, m, &cBinop_2DnJNMZC_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_2DnJNMZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_UNXGPv6B_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cCast_j7AzyIa8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5tR11xNT, HV_BINOP_DIVIDE, 1, m, &cBinop_5tR11xNT_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_F1p5R7BG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_apfruF3U, 0, m, &cVar_apfruF3U_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_F5EOfuIs, 0, m, &cVar_F5EOfuIs_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_ZwzIVXzw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_F5EOfuIs, 0, m, &cVar_F5EOfuIs_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_v4OXz9vW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_apfruF3U, 0, m, &cVar_apfruF3U_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_TFz9yHS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZwzIVXzw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v4OXz9vW_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_pWrvW9z0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZwzIVXzw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v4OXz9vW_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_9aOiP6jF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZwzIVXzw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v4OXz9vW_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_cIOeOfoW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZwzIVXzw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v4OXz9vW_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_6ZaC85Zv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZwzIVXzw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v4OXz9vW_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_r48NksEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZwzIVXzw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v4OXz9vW_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_plHFKk5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZwzIVXzw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v4OXz9vW_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_d421UpGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZwzIVXzw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v4OXz9vW_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_h8ig0Gb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZwzIVXzw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v4OXz9vW_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_sfEwL9uz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZwzIVXzw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v4OXz9vW_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_780GsYow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZwzIVXzw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v4OXz9vW_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_JJuc3ZHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZwzIVXzw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v4OXz9vW_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_Z2XVEp3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZwzIVXzw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v4OXz9vW_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_FgfnudKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jdzPpzA6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_U4ik4Z3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jdzPpzA6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_WAbWQPQd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gZzSSU8I, 0, m, &cVar_gZzSSU8I_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Ot4ESpvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JiYsHq0O, 0, m, &cVar_JiYsHq0O_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_avg2IKK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hQzDUSQG, 0, m, &cVar_hQzDUSQG_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_V1QLpMKv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jdzPpzA6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_20RbRPEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jdzPpzA6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_5YHa2BTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BqdIorUW, 0, m, &cVar_BqdIorUW_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_sFzBnp5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_edhyZzpP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aDPdxZCX_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_sQrpIVr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_q5VQEoIJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9zIUFZxh_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_q5VQEoIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hkNIAr4t, 1, m, &cIf_hkNIAr4t_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_9zIUFZxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YjfbV3P2, 0, m, &cVar_YjfbV3P2_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_edhyZzpP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IAOGDVUp, 1, m, &cIf_IAOGDVUp_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_aDPdxZCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BqdIorUW, 0, m, &cVar_BqdIorUW_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_UkjPPDpj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_WAbWQPQd_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_su2Pli4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Ot4ESpvn_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_tvsOHhHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_avg2IKK2_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_ujzFHYb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YjfbV3P2, 0, m, &cVar_YjfbV3P2_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_XMPgWty8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_av0A6fui_sendMessage(_c, 0, m);
  cMsg_WPQ4uvUk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_FecfLnw5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7pVWNaUG_sendMessage(_c, 0, m);
  cMsg_zcEWaIed_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_sClDORxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_8roFm7Xa_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_7e2UGMwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kwJHUfqg, 0, m, &cVar_kwJHUfqg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_C8jfvado, 0, m, &cVar_C8jfvado_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qYtRJvc8, 0, m, &cVar_qYtRJvc8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dSYIrcS4, 0, m, &cVar_dSYIrcS4_sendMessage);
  cMsg_o6iKFmqA_sendMessage(_c, 0, m);
  cMsg_qCpV1uVt_sendMessage(_c, 0, m);
  cMsg_BAYV0xGK_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_pGgS9SB2, 0, m, &cVar_pGgS9SB2_sendMessage);
  cMsg_IXX8RKVk_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NBbQFHat, 0, m, &cVar_NBbQFHat_sendMessage);
  cMsg_gJENzuI2_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_dsKKbW8E, 0, m, &cVar_dsKKbW8E_sendMessage);
  cMsg_kGFRQMK0_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_B9F0hr00, 0, m, &cVar_B9F0hr00_sendMessage);
  cMsg_lhnW9Nf6_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_l29CM6kB, 0, m, &cVar_l29CM6kB_sendMessage);
  cMsg_5vxKq0ey_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_iVvxybfe, 0, m, &cVar_iVvxybfe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5lboDTLa, 0, m, &cVar_5lboDTLa_sendMessage);
  cMsg_HChowd2n_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_UfOhDbZI, 0, m, &cVar_UfOhDbZI_sendMessage);
  cMsg_sagq6xtH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_Qu9G8O3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_4VTo2Kbw_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_HMZVD8De_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Mje0XV8g, 0, m, &cVar_Mje0XV8g_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_MkD0rsbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Pra0GLr2, 0, m, &cVar_Pra0GLr2_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_PjpFFJXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9QqpRRxf_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DLAY::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_uPCq4KBN, VOf(Bf0));
    __hv_line_f(&sLine_myOrod6H, VOf(Bf1));
    __hv_tabhead_f(&sTabhead_oNUjtSqh, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf3), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_NkZdNlAI, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_J7p8ddtR, VOf(Bf1));
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf3));
    __hv_varread_f(&sVarf_bavNXfMB, VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_lt_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_cast_fi(VIf(Bf4), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_bO4Uo0n9, VIi(Bi1), VOf(Bf4));
    __hv_tabread_if(&sTabread_MQJbVtkP, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf4), VIf(Bf1), VOf(Bf4));
    __hv_sub_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_OzLT9tNy, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_scJgD87b, VOf(Bf0));
    __hv_line_f(&sLine_StLxOLEC, VOf(Bf4));
    __hv_tabhead_f(&sTabhead_QrH8jDE3, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf5), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_hlSLktwM, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_2dsot4aa, VOf(Bf4));
    __hv_min_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf5));
    __hv_varread_f(&sVarf_x3jtpfF0, VOf(Bf4));
    __hv_zero_f(VOf(Bf6));
    __hv_lt_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_and_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_cast_fi(VIf(Bf6), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_iKnzqGuf, VIi(Bi1), VOf(Bf6));
    __hv_tabread_if(&sTabread_DhFYJ0xy, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf6));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf6), VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_6LWtY6OA, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(I1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_fIncjiUm, VOf(Bf0));
    __hv_add_f(VIf(I0), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_SxVRcT5x, VIf(Bf0));
    __hv_varread_f(&sVarf_oJyhzKuR, VOf(Bf0));
    __hv_add_f(VIf(I1), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_gkkx0VgZ, VIf(Bf0));
    __hv_varread_f(&sVarf_224GNFqg, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_KgHxuHor, VOf(Bf1));
    __hv_rpole_f(&sRPole_GczPZLXX, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_NNEzqUbh, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_xkzqbu0c, VOf(Bf1));
    __hv_rpole_f(&sRPole_FWpNqiH2, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_2u2DPBE9, VOf(Bf0));
    __hv_rpole_f(&sRPole_zKaONJMf, VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_7asqsh7h, VIf(Bf0), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Q0ROTXk4, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_O2K0SRyR, VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_fTPoKJC7, VOf(Bf0));
    __hv_varread_f(&sVarf_Vjywfy44, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_2x0yYthn, VOf(Bf4));
    __hv_rpole_f(&sRPole_twC5YHEN, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_mBJxROzC, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_EG1fzdfc, VOf(Bf4));
    __hv_rpole_f(&sRPole_FggNpMLl, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_EbVtG4qh, VOf(Bf6));
    __hv_rpole_f(&sRPole_W1XUknSA, VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_HLGwL1JR, VIf(Bf6), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_wT5MGlMC, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_Wp2g1IH5, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_8lBULhkW, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_fIncjiUm, VIf(Bf6));
    __hv_line_f(&sLine_evl7FYEh, VOf(Bf6));
    __hv_line_f(&sLine_UTXAiCYF, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf4), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_oJyhzKuR, VIf(Bf0));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DLAY::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DLAY::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
