/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_DLAY_HPP_
#define _HEAVY_CONTEXT_WSTD_DLAY_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlBinop.h"
#include "HvControlCast.h"
#include "HvSignalDel1.h"
#include "HvSignalVar.h"
#include "HvControlVar.h"
#include "HvSignalTabwrite.h"
#include "HvControlSystem.h"
#include "HvSignalRPole.h"
#include "HvControlSlice.h"
#include "HvSignalTabread.h"
#include "HvTable.h"
#include "HvControlIf.h"
#include "HvControlDelay.h"
#include "HvMath.h"
#include "HvSignalLine.h"
#include "HvControlUnop.h"

class Heavy_WSTD_DLAY : public HeavyContext {

 public:
  Heavy_WSTD_DLAY(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_DLAY();

  const char *getName() override { return "WSTD_DLAY"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CROSS = 0xB6A8F09D, // Cross
        FEEDBACK = 0x57157946, // Feedback
        MIX = 0x97D46AC6, // Mix
        SYNC = 0x4A331B66, // Sync
        TIME = 0x58E5C2DB, // Time
        TIMESYNC = 0x49107604, // TimeSync
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_JiYsHq0O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZlUMLQSo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hQzDUSQG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gZzSSU8I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MQdkcQy4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_6p9Ls8GJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kwJHUfqg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_LByVWikV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_jdzPpzA6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_6h9bBmy1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_C8jfvado_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_E24GFlK8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_n90okzJb_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Oh9ijsuV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qYtRJvc8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_h7W4Tutx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8roFm7Xa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XmTeikDe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_shUSZOve_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_qWTHNQpy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_waBmQ5m2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z8zEre3Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uKK5jGHk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vbuPbBA3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nX4lD3pG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3EbWr2cv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VCWAIZhs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5xS4DwEx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7Ymw9qoC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4VTo2Kbw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_35XHvb3W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J6eZNFcw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_89VUwOLa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_STUocZAf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Obq4k0xy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ga2QpfTw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zve6ma57_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k1N9pZKF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IiKUi83o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HlrBjMXK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_6XMvJp1S_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_eIyXarPB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dSYIrcS4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_c1ddE1qb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o6iKFmqA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ko5VrUFZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Gh39mUku_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_8d5Srksw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_6rxn2sQx_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_TtOKXV3T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_7926x3Sv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xMcaFkDa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8r8nkV8I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VMIsRzmh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ue3hOBa3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d9LM1E8V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yg3AnBI2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qCpV1uVt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_oKyK5Xba_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_pqwu14R0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_HRx3dgvZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_VCKoBuVG_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_slCAPRZa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_cw8bHeZ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_h4b6Q13l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yoVi4ZOu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SsLJWjGb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_j1Fn0u03_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kqMRngnJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qbzlC9iO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pGgS9SB2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BAYV0xGK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8w11Zo3G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1skPyP1i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oGpyh53M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cSBIsUpY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8S35bcMe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yU5mGpdd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O3PmU0Fg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NBbQFHat_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IXX8RKVk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JzlKbxSm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pHinPtYB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Dd3xqyJH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XE6NtNtw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LHH1BXrO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HANt8vbk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1pXE15KY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9biRsh1G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kRRVEdVp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dsKKbW8E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gJENzuI2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_INzt2aD4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HDPVfUct_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s4uivo9J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FdscIbaH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_696b4rKa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KJCnUNNX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aWOLlpf0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q9EPVC2F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WsvxntiQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HChowd2n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7ZSSixCW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5lboDTLa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_QuPCKAfA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4PetTCMW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GU8atioA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ug0cJA6A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sagq6xtH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_WRkY4UOp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UfOhDbZI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_5f0a84Ld_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8ouM4FDa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QtE8Olhu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LZyL0pOq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_B9F0hr00_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kGFRQMK0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ERVm3KPT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dET8BYgu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pfb7qdCU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DPQ8Q2sK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aMAIZl7F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QplMYuSL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NVSeOZD2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_l29CM6kB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lhnW9Nf6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_qD6Cfd96_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BD5VE331_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dhnBAJDq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WgRLbFeb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4k5QKoiu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HmBs65oR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zj351ysT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2ypCwzCO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nSYwrB8p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iVvxybfe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5vxKq0ey_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_yaxhyqVl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bZ9u1j2d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PHcsnj3X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fYT46wqJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pChy46Pj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VBFpoJui_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tuvCfGBh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4nQ5fJ2p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IfusATls_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ELffi3de_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7sTZMEfy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tUV9Tbcu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y6w0PjZX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2OSfud9g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n7d850Je_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fkaVl5vX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m3ykVZEN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_av0A6fui_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WPQ4uvUk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7pVWNaUG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zcEWaIed_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Mje0XV8g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xNCNhnJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_IAOGDVUp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hkNIAr4t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YjfbV3P2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BqdIorUW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_apfruF3U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_F5EOfuIs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_UNXGPv6B_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_3qBzXGNt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_SZYl4vyc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gP0mbNOU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vY0viXIF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WdHjZiaR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N5F4GrJY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7OtzAZTd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UWTgNOPW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_d1gMNPA8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Pra0GLr2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_9QqpRRxf_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_XPPouK35_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1AxWHjeG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nuP9C3zU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FHrlcNZ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YWo21gHV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dkml0jSK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ot61OeJw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_umIH8hZR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CNcU6Vfk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_owGL5w04_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RbpSlcrw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Vfqik9ze_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LX3ZeqI9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5tR11xNT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2DnJNMZC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_j7AzyIa8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_F1p5R7BG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZwzIVXzw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_v4OXz9vW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TFz9yHS7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pWrvW9z0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9aOiP6jF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cIOeOfoW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6ZaC85Zv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r48NksEV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_plHFKk5h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d421UpGx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_h8ig0Gb0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sfEwL9uz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_780GsYow_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JJuc3ZHV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Z2XVEp3C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FgfnudKC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U4ik4Z3D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WAbWQPQd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ot4ESpvn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_avg2IKK2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V1QLpMKv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_20RbRPEH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5YHa2BTH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sFzBnp5f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sQrpIVr6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_q5VQEoIJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9zIUFZxh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_edhyZzpP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aDPdxZCX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UkjPPDpj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_su2Pli4W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tvsOHhHF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ujzFHYb5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XMPgWty8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FecfLnw5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sClDORxF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7e2UGMwg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Qu9G8O3H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HMZVD8De_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MkD0rsbk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PjpFFJXI_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_uPCq4KBN;
  SignalLine sLine_myOrod6H;
  SignalTabhead sTabhead_oNUjtSqh;
  SignalTabread sTabread_bO4Uo0n9;
  SignalTabread sTabread_MQJbVtkP;
  SignalLine sLine_OzLT9tNy;
  SignalLine sLine_scJgD87b;
  SignalLine sLine_StLxOLEC;
  SignalTabhead sTabhead_QrH8jDE3;
  SignalTabread sTabread_iKnzqGuf;
  SignalTabread sTabread_DhFYJ0xy;
  SignalLine sLine_6LWtY6OA;
  SignalTabwrite sTabwrite_SxVRcT5x;
  SignalTabwrite sTabwrite_gkkx0VgZ;
  SignalRPole sRPole_GczPZLXX;
  SignalRPole sRPole_FWpNqiH2;
  SignalRPole sRPole_zKaONJMf;
  SignalDel1 sDel1_7asqsh7h;
  SignalLine sLine_O2K0SRyR;
  SignalLine sLine_fTPoKJC7;
  SignalRPole sRPole_twC5YHEN;
  SignalRPole sRPole_FggNpMLl;
  SignalRPole sRPole_W1XUknSA;
  SignalDel1 sDel1_HLGwL1JR;
  SignalLine sLine_Wp2g1IH5;
  SignalLine sLine_8lBULhkW;
  SignalLine sLine_evl7FYEh;
  SignalLine sLine_UTXAiCYF;
  ControlVar cVar_JiYsHq0O;
  ControlVar cVar_ZlUMLQSo;
  ControlVar cVar_hQzDUSQG;
  ControlVar cVar_gZzSSU8I;
  ControlSlice cSlice_6p9Ls8GJ;
  ControlVar cVar_kwJHUfqg;
  ControlSlice cSlice_6h9bBmy1;
  ControlVar cVar_C8jfvado;
  ControlSlice cSlice_Oh9ijsuV;
  ControlVar cVar_qYtRJvc8;
  ControlBinop cBinop_8roFm7Xa;
  ControlBinop cBinop_XmTeikDe;
  ControlBinop cBinop_waBmQ5m2;
  ControlBinop cBinop_Z8zEre3Q;
  ControlBinop cBinop_nX4lD3pG;
  ControlBinop cBinop_VCWAIZhs;
  ControlBinop cBinop_5xS4DwEx;
  ControlBinop cBinop_7Ymw9qoC;
  ControlBinop cBinop_4VTo2Kbw;
  ControlBinop cBinop_35XHvb3W;
  ControlBinop cBinop_J6eZNFcw;
  ControlBinop cBinop_89VUwOLa;
  ControlBinop cBinop_ga2QpfTw;
  ControlBinop cBinop_k1N9pZKF;
  ControlBinop cBinop_IiKUi83o;
  ControlBinop cBinop_HlrBjMXK;
  ControlSlice cSlice_eIyXarPB;
  ControlVar cVar_dSYIrcS4;
  ControlDelay cDelay_Gh39mUku;
  ControlDelay cDelay_8d5Srksw;
  ControlBinop cBinop_TtOKXV3T;
  HvTable hTable_7926x3Sv;
  ControlBinop cBinop_8r8nkV8I;
  ControlDelay cDelay_pqwu14R0;
  ControlDelay cDelay_HRx3dgvZ;
  ControlBinop cBinop_slCAPRZa;
  HvTable hTable_cw8bHeZ6;
  ControlBinop cBinop_yoVi4ZOu;
  ControlVar cVar_pGgS9SB2;
  ControlBinop cBinop_1skPyP1i;
  ControlBinop cBinop_oGpyh53M;
  SignalVarf sVarf_KgHxuHor;
  ControlBinop cBinop_8S35bcMe;
  ControlBinop cBinop_yU5mGpdd;
  ControlBinop cBinop_O3PmU0Fg;
  SignalVarf sVarf_224GNFqg;
  ControlVar cVar_NBbQFHat;
  ControlBinop cBinop_pHinPtYB;
  ControlBinop cBinop_Dd3xqyJH;
  SignalVarf sVarf_xkzqbu0c;
  ControlBinop cBinop_LHH1BXrO;
  ControlBinop cBinop_HANt8vbk;
  ControlBinop cBinop_1pXE15KY;
  SignalVarf sVarf_NNEzqUbh;
  ControlBinop cBinop_9biRsh1G;
  ControlBinop cBinop_kRRVEdVp;
  SignalVarf sVarf_2u2DPBE9;
  ControlVar cVar_dsKKbW8E;
  ControlBinop cBinop_HDPVfUct;
  ControlBinop cBinop_s4uivo9J;
  ControlBinop cBinop_696b4rKa;
  ControlBinop cBinop_KJCnUNNX;
  ControlBinop cBinop_aWOLlpf0;
  ControlBinop cBinop_Q9EPVC2F;
  ControlBinop cBinop_WsvxntiQ;
  SignalVarf sVarf_Q0ROTXk4;
  ControlVar cVar_5lboDTLa;
  ControlBinop cBinop_4PetTCMW;
  ControlBinop cBinop_ug0cJA6A;
  SignalVarf sVarf_bavNXfMB;
  SignalVarf sVarf_NkZdNlAI;
  SignalVarf sVarf_J7p8ddtR;
  ControlVar cVar_UfOhDbZI;
  ControlBinop cBinop_8ouM4FDa;
  ControlBinop cBinop_LZyL0pOq;
  SignalVarf sVarf_x3jtpfF0;
  SignalVarf sVarf_hlSLktwM;
  SignalVarf sVarf_2dsot4aa;
  ControlVar cVar_B9F0hr00;
  ControlBinop cBinop_dET8BYgu;
  ControlBinop cBinop_pfb7qdCU;
  SignalVarf sVarf_2x0yYthn;
  ControlBinop cBinop_aMAIZl7F;
  ControlBinop cBinop_QplMYuSL;
  ControlBinop cBinop_NVSeOZD2;
  SignalVarf sVarf_Vjywfy44;
  ControlVar cVar_l29CM6kB;
  ControlBinop cBinop_BD5VE331;
  ControlBinop cBinop_dhnBAJDq;
  SignalVarf sVarf_EG1fzdfc;
  ControlBinop cBinop_4k5QKoiu;
  ControlBinop cBinop_HmBs65oR;
  ControlBinop cBinop_Zj351ysT;
  SignalVarf sVarf_mBJxROzC;
  ControlBinop cBinop_2ypCwzCO;
  ControlBinop cBinop_nSYwrB8p;
  SignalVarf sVarf_EbVtG4qh;
  ControlVar cVar_iVvxybfe;
  ControlBinop cBinop_bZ9u1j2d;
  ControlBinop cBinop_PHcsnj3X;
  ControlBinop cBinop_pChy46Pj;
  ControlBinop cBinop_VBFpoJui;
  ControlBinop cBinop_tuvCfGBh;
  ControlBinop cBinop_4nQ5fJ2p;
  ControlBinop cBinop_IfusATls;
  SignalVarf sVarf_wT5MGlMC;
  SignalVarf sVarf_fIncjiUm;
  SignalVarf sVarf_oJyhzKuR;
  ControlVar cVar_Mje0XV8g;
  ControlBinop cBinop_xNCNhnJr;
  ControlIf cIf_IAOGDVUp;
  ControlIf cIf_hkNIAr4t;
  ControlVar cVar_YjfbV3P2;
  ControlVar cVar_BqdIorUW;
  ControlVar cVar_apfruF3U;
  ControlVar cVar_F5EOfuIs;
  ControlSlice cSlice_3qBzXGNt;
  ControlSlice cSlice_SZYl4vyc;
  ControlVar cVar_gP0mbNOU;
  ControlIf cIf_vY0viXIF;
  ControlBinop cBinop_7OtzAZTd;
  ControlVar cVar_Pra0GLr2;
  ControlBinop cBinop_5tR11xNT;
  ControlBinop cBinop_2DnJNMZC;
  ControlBinop cBinop_WAbWQPQd;
  ControlBinop cBinop_Ot4ESpvn;
  ControlBinop cBinop_avg2IKK2;
  ControlBinop cBinop_5YHa2BTH;
  ControlBinop cBinop_sFzBnp5f;
  ControlBinop cBinop_sQrpIVr6;
};

#endif // _HEAVY_CONTEXT_WSTD_DLAY_HPP_
